package smapro

import (
	"encoding/json"
	"fmt"
	"git.168cad.top/go/wechat-client-sdk/core/response"
	"git.168cad.top/go/wechat-client-sdk/httpclient"
)

// GetUserPhoneNumber 换取用户手机号
// https://developers.weixin.qq.com/miniprogram/dev/OpenApiDoc/user-info/phone-number/getPhoneNumber.html
func GetUserPhoneNumber(code string, accessToken string) (*PhoneNumberResponse, error) {
	result := &PhoneNumberResponse{}
	url := fmt.Sprintf("https://api.weixin.qq.com/wxa/business/getuserphonenumber?access_token=%s", accessToken)
	bodyParam := phoneNumberParam{code}

	bs,err := httpclient.Post(url,nil, bodyParam)
	if err != nil {
		return nil, err
	}

	if err1 := json.Unmarshal(bs, result);err1 !=nil{
		return nil, err1
	}
	return result, nil
}

type phoneNumberParam struct {
	Code string `json:"code"`
}

type PhoneNumberResponse struct {
	response.MiniProgramResponse
	PhoneInfo PhoneInfoResponse `json:"phone_info"`
}

type PhoneInfoResponse struct {
	PhoneNumber string `json:"phoneNumber"`
	PurePhoneNumber string `json:"purePhoneNumber"`
	CountryCode string `json:"countryCode"`
	Watermark WatermarkResponse `json:"watermark"`
}

type WatermarkResponse struct {
	Timestamp int32 `json:"timestamp"`
	Appid string `json:"appid"`
}
